@@ -28,12 +28,12 @@ import time
 startTimestamp = time.time()
 import os
 import marshal
-import traceback
 import imp
 import platform
 
 # initialize logging
 from core import modrana_log
+from core.signal import Signal
 modrana_log.init_logging()
 import logging
 log = logging.getLogger("")
@@ -49,7 +49,7 @@ def setCorrectCWD():
     # effect such as modRana not finding modules or
     currentAbsolutePath = os.path.dirname(os.path.abspath(__file__))
     if USING_QRC:
-        # we are runing from qrc, so just use the qrc:/ prefix as CWD,
+        # we are running from qrc, so just use the qrc:/ prefix as CWD,
         # no need to chdir
         currentAbsolutePath = "qrc:/"
     else:
@@ -125,6 +125,8 @@ class ModRana(object):
             'name': ""
         }
 
+        self.notificationTriggered = Signal()
+
         self.mapRotationAngle = 0 # in radians
         self.notMovingSpeed = 1 # in m/s
 
@@ -390,7 +392,7 @@ class ModRana(object):
     def _listAvailableGUIModulesByID(self):
         return self._getModuleNamesFromFolder(GUI_MODULES_FOLDER)
 
-    def _loadModule(self, importName, modRanaName):
+    def _loadModule(self, importName, moduleName):
         """load a single module by name from path"""
         startM = time.clock()
         fp = None
@@ -404,19 +406,16 @@ class ModRana(object):
                 fp, pathName, description = imp.find_module(importName, ALL_MODULE_FOLDERS)
                 a = imp.load_module(importName, fp, pathName, description)
 
-            initInfo = self.initInfo
-            initInfo['name'] = modRanaName
-            initInfo['importName'] = importName
-            module = a.getModule(self.m, self.d, initInfo)
-            self.m[modRanaName] = module
+            module = a.getModule(self, moduleName, importName)
+            self.m[moduleName] = module
             log.info(" * %s: %s (%1.2f ms)",
-                     modRanaName,
-                     self.m[modRanaName].__doc__,
+                     moduleName,
+                     self.m[moduleName].__doc__,
                      (1000 * (time.clock() - startM))
             )
             return module
         except Exception:
-            log.exception("module: %s/%s failed to load", importName, modRanaName)
+            log.exception("module: %s/%s failed to load", importName, moduleName)
             return None
         finally:
             if fp:
@@ -622,7 +621,7 @@ class ModRana(object):
         if key in self.watches:
             remove = lambda x: x[0] == id
             self.watches[key][:] = [x for x in self.watches[key] if not remove(x)]
-        log.error("can't remove watch - key does not exist, watchId:", id)
+        log.error("can't remove watch - key does not exist, watchId: %s", id)
 
     def _notifyWatcher(self, key, oldValue):
         """run callbacks registered on an options key
@@ -730,11 +729,18 @@ class ModRana(object):
 
     def notify(self, message, msTimeout=0, icon=""):
         log.info("modRana notify: %s", message)
-        notify = self.m.get('notification')
-        if notify:
-            # the notification module counts timeout in seconds
-            sTimeout = msTimeout / 1000.0
-            notify.handleNotification(message, sTimeout, icon)
+        # trigger the notification signal - this will
+        # trigger an actual notification by one of the
+        # notification systems connected to the notification
+        # signal (if any)
+        self.notificationTriggered(message, msTimeout, icon)
+
+
+        # notify = self.m.get('notification')
+        # if notify:
+        #     # the notification module counts timeout in seconds
+        #     sTimeout = msTimeout / 1000.0
+        #     notify.handleNotification(message, sTimeout, icon)
 
     def getModes(self):
         """return supported modes"""
@@ -800,7 +806,7 @@ class ModRana(object):
             # remove keys marked as nonpersistent
             self.d['keyModifiers'] = self.keyModifiers
             d = self._removeNonPersistentOptions(self.d)
-            marshal.dump(d, f)
+            marshal.dump(d, f, 2)
             f.close()
             log.info("options successfully saved")
         except IOError:
@@ -911,10 +917,15 @@ def start(argv=None):
                       injected by QML
     """
     if not argv: argv = []
-    log.debug("argv from QML:\n%s", argv)
-    sys.argv = ["modrana.py"]
-    sys.argv.extend(argv)
-    log.debug("full argv:\n%s", sys.argv)
+    # only assign fake values to argv if argv is empty or missing,
+    # so that real command line arguments are not overwritten
+    if not hasattr(sys, "argv") or not isinstance(sys.argv, list) or not sys.argv:
+        log.debug("argv from QML:\n%s", argv)
+        sys.argv = ["modrana.py"]
+    # only log full argv if it was extended
+    if argv:
+        sys.argv.extend(argv)
+        log.debug("full argv:\n%s", sys.argv)
 
     global modrana
     global dmod
