@@ -23,6 +23,8 @@ from modules.device_modules.base_device_module import DeviceModule
 
 import os
 
+from core import constants
+
 MAIN_MODRANA_DATA_FOLDER = "/sdcard/modrana"  # main modRana data folder on Android
 MAP_FOLDER_PATH = os.path.join(MAIN_MODRANA_DATA_FOLDER, "maps")
 ROUTING_DATA_FOLDER_PATH = os.path.join(MAIN_MODRANA_DATA_FOLDER, "routing_data")
@@ -30,15 +32,15 @@ TRACKLOG_FOLDER_PATH = os.path.join(MAIN_MODRANA_DATA_FOLDER, "tracklogs")
 DEBUG_LOG_FOLDER_PATH = os.path.join(MAIN_MODRANA_DATA_FOLDER, "debug_logs")
 POI_FOLDER_PATH = os.path.join(MAIN_MODRANA_DATA_FOLDER, "poi")
 
-def getModule(m, d, i):
-    return Android(m, d, i)
+def getModule(*args, **kwargs):
+    return Android(*args, **kwargs)
 
 
 class Android(DeviceModule):
     """A modRana device-specific module for Android"""
 
-    def __init__(self, m, d, i):
-        DeviceModule.__init__(self, m, d, i)
+    def __init__(self, *args, **kwargs):
+        DeviceModule.__init__(self, *args, **kwargs)
         self.tempUnfullscreen = False
 
     def getDeviceIDString(self):
@@ -94,3 +96,13 @@ class Android(DeviceModule):
     def getDeviceType(self):
         # TODO: device type detection
         return None
+
+    @property
+    def defaultTileStorageType(self):
+        """Use Sqlite tile storage by default on Android to both
+        make sure the tiles would not be indexed into the gallery and also as
+        sharing the tile image files with another mapping application is not
+        very probably on Android. And who knows how would the usual Android
+        filesystems handle such a big amount of very small files.
+        """
+        return constants.TILE_STORAGE_SQLITE
