@@ -55,8 +55,8 @@ def newlines2brs(text):
     """ QML uses <br> instead of \n for linebreak """
     return re.sub('\n', '<br>', text)
 
-def getModule(m, d, i):
-    return QMLGUI(m, d, i)
+def getModule(*args, **kwargs):
+    return QMLGUI(*args, **kwargs)
 
 def point2dict(point):
     """ Convert a Point instance to a dict
@@ -77,8 +77,8 @@ def point2dict(point):
 class QMLGUI(GUIModule):
     """A Qt + QML GUI module"""
 
-    def __init__(self, m, d, i):
-        GUIModule.__init__(self, m, d, i)
+    def __init__(self, *args, **kwargs):
+        GUIModule.__init__(self, *args, **kwargs)
 
         # some constants
         self.msLongPress = 400
@@ -86,6 +86,12 @@ class QMLGUI(GUIModule):
         self.firstTimeSignal = signal.Signal()
         size = (800, 480) # initial window size
 
+        # positioning related
+        self._pythonPositioning = False
+
+        # we handle notifications by forwarding them to the QML context
+        self.modrana.notificationTriggered.connect(self._dispatchNotificationCB)
+
         # register exit handler
         #pyotherside.atexit(self._shutdown)
         # FIXME: for some reason the exit handler is never
@@ -142,14 +148,22 @@ class QMLGUI(GUIModule):
 
         # log for log messages from the QML context
         self.qml_log = qml_log
+        # queue a notification to QML context that
+        # a Python loggers is available
+        pyotherside.send("loggerAvailable")
 
         # tracklogs
         self.tracklogs = Tracklogs(self)
 
+        #routing
+        self.routing = Routing(self)
+
     def firstTime(self):
         # trigger the first time signal
         self.firstTimeSignal()
 
+        self.modules.location.positionUpdate.connect(self._pythonPositionUpdateCB)
+
     def _shutdown(self):
         """Called by PyOtherSide once the QML side is shutdown.
         """
@@ -186,19 +200,18 @@ class QMLGUI(GUIModule):
     def hasNotificationSupport(self):
         return True
 
-    def notify(self, text, msTimeout=5000, icon=""):
-        """trigger a notification using the Qt Quick Components
-        InfoBanner notification"""
-        # TODO: implement this
+    def _dispatchNotificationCB(self, text, msTimeout=5000, icon=""):
+        """Let the QML context know that it should show a notification
 
-        #    # QML uses <br> instead of \n for linebreak
-        #    text = newlines2brs(text)
-        #    self.log.debug("notify:\n message: %s, timeout: %d" % (text, msTimeout))
-        #    if self.rootObject:
-        #      self.rootObject.notify(text, msTimeout)
-        #    else:
-        #      self._notificationQueue.append((text, msTimeout, icon))
-        return
+        :param str text: text of the notification message
+        :param int msTimeout: how long to show the notification in ms
+        """
+
+        self.log.debug("notify:\n message: %s, timeout: %d" % (text, msTimeout))
+        pyotherside.send("pythonNotify", {
+            "message" : newlines2brs(text),  # QML uses <br> in place of \n
+            "timeout" : msTimeout
+        })
 
     def openUrl(self, url):
         # TODO: implement this
@@ -226,6 +239,10 @@ class QMLGUI(GUIModule):
             return version
 
     def setPosition(self, posDict):
+        if self._pythonPositioning:
+            # ignore the setPosition call if Python-side positioning
+            # is used as the Python side already has fresh position data
+            return
         lat, lon = float(posDict["latitude"]), float(posDict["longitude"])
         elevation = float(posDict["elevation"])
         metersPerSecSpeed = float(posDict["speedMPS"])  # m/s
@@ -255,6 +272,23 @@ class QMLGUI(GUIModule):
         self.set('locationUpdated', time.time())
         # TODO: move part of this to the location module ?
 
+    def _pythonPositionUpdateCB(self, fix):
+        self._pythonPositioning = True
+        if fix.position:
+            (lat, lon) = fix.position
+        else:
+            (lat, lon) = None
+        pyotherside.send("pythonPositionUpdate", {
+            "latitude" : lat,
+            "longitude" : lon,
+            "altitude" : fix.altitude,
+            "speed" : fix.speed,
+            "horizontalAccuracy" : fix.horizontal_accuracy,
+            "verticalAccuracy" : fix.vertical_accuracy,
+            "timestamp" : fix.timestamp,
+            "valid" : bool(fix.position)
+        })
+
     def _selectImageProviderCB(self, imageId, requestedSize):
         originalImageId = imageId
         providerId = ""
@@ -330,7 +364,9 @@ class QMLGUI(GUIModule):
             "layerTree" : self.modules.mapLayers.getLayerTree(),
             "dictOfLayerDicts" : self.modules.mapLayers.getDictOfLayerDicts(),
             "themesFolderPath" : os.path.abspath(self.modrana.paths.getThemesFolderPath()),
-            "sailfish" : self.dmod.getDeviceIDString() == "jolla"
+            "sailfish" : self.dmod.getDeviceIDString() == "jolla",
+            "hiDPI" : self.highDPI,
+            "defaultTileStorageType" : self.modrana.dmod.defaultTileStorageType
         }
         return values
 
@@ -776,6 +812,28 @@ class Tracklogs(object):
 
     def __init__(self, gui):
         self.gui = gui
+        self.gui.firstTimeSignal.connect(self._firstTimeCB)
+        self._sendUpdates = True
+
+    def _firstTimeCB(self):
+        # connect to the tracklog update signal, so that we can send
+        # track logging state updates to the GUI
+        self.gui.modules.tracklog.tracklogUpdated.connect(self._sendUpdateCB)
+
+    def _sendUpdateCB(self):
+        """Tracklog has been updated, send the updated info dict to GUI"""
+        if self._sendUpdates:
+            pyotherside.send("tracklogUpdated", self.gui.modules.tracklog.getStatusDict())
+
+    def setSendUpdates(self, value):
+        """Set if tracklog updates should be sent to the GUI layer or not.
+        This is used to disable updates when the track recording page is not visible.
+        """
+        self._sendUpdates = value
+        if value:
+            self.gui.log.debug("tracklog: enabling logging status updates")
+        else:
+            self.gui.log.debug("tracklog: disabling logging status updates")
 
     def sailfishSymlinkExists(self):
         """Report if the easy access symlink on Sailfish OS for tracklogs exists
@@ -810,3 +868,32 @@ class Tracklogs(object):
                 self.gui.log.info("tracklogs: sailfish tracklogs symlink removed")
             except Exception:
                 self.gui.log.exception("tracklogs: sailfish tracklogs symlink removed")
+
+class Routing(object):
+    """Qt 5 GUI specific stuff for routing support"""
+
+    def __init__(self, gui):
+        self.gui = gui
+        self.gui.firstTimeSignal.connect(self._firstTimeCB)
+        self._sendUpdates = True
+
+    def _firstTimeCB(self):
+        self.gui.modules.route.routingDone.connect(self._routingDoneCB)
+
+    def _routingDoneCB(self, result):
+        if result and result.returnCode == constants.ROUTING_SUCCESS:
+            routePoints = result.route.getPointsLLE()
+            messagePoints = result.route.getMessagePoints()
+            messagePointsLLEM = []
+            for mp in messagePoints:
+                messagePointsLLEM.append(mp.getLLEM())
+            # also add a point for the route end
+            if routePoints:
+                lastPoint = routePoints[-1]
+                lastPointMessage = "You <b>should</b> be near the destination."
+                messagePointsLLEM.append((lastPoint[0], lastPoint[1],
+                                          lastPoint[2], lastPointMessage))
+            self.gui.log.debug("routing successful")
+            pyotherside.send("routeReceived", routePoints, messagePointsLLEM)
+        else:
+            self.gui.log.debug("routing failed")
\ No newline at end of file
