@@ -25,16 +25,14 @@ from core import constants
 # identifies item as a group
 GROUP_IDENTIFIER = "groupIdentifier"
 
-
-def getModule(m, d, i):
-    return Options(m, d, i)
-
+def getModule(*args, **kwargs):
+    return Options(*args, **kwargs)
 
 class Options(RanaModule):
     """Handle options"""
 
-    def __init__(self, m, d, i):
-        RanaModule.__init__(self, m, d, i)
+    def __init__(self, *args, **kwargs):
+        RanaModule.__init__(self, *args, **kwargs)
         self.options = {}
         # for fast searching defaults for corresponding keys
         self.keyDefault = {}
@@ -563,7 +561,7 @@ class Options(RanaModule):
                [('files', "files (default, more space used)"),
                 ('sqlite', "sqlite (new, less space used)")],
                group,
-               'files')
+               self.modrana.dmod.defaultTileStorageType)
         addBoolOpt("Store downloaded tiles", "storeDownloadedTiles", group, True)
         addOpt("Sqlite tile db commit interval", "sqliteTileDatabaseCommitInterval",
                [(1, "1 second", notifyRestartNeeded),
@@ -953,7 +951,7 @@ class Options(RanaModule):
         if self.dmod.getLocationType() == 'gpsd':
             knots = "knots per second"
             meters = "meters per second"
-            if self.device == 'neo':
+            if self.dmod.getDeviceIDString() == 'neo':
                 knots = "knots per second (old SHR)"
                 meters = "meters per second (new SHR)"
             addOpt("GPSD reports speed in", "gpsdSpeedUnit",
@@ -1450,9 +1448,7 @@ class Options(RanaModule):
                                                dy,
                                                None,
                                                "generic", # background for a 3x1 icon
-                                               "")
-                    # due to the button on the right, register a slightly smaller area
-                    clickHandler.registerXYWH(x4, y, w - smallButtonW, dy, onClick)
+                                               onClick)
 
                     # draw mode specific combined toggle & indicator
                     if self.modrana.hasKeyModifierInMode(variable, mode):
@@ -1469,7 +1465,8 @@ class Options(RanaModule):
                                                smallButtonH,
                                                toggleText,
                                                "generic",
-                                               modeSpecToggleAction)
+                                               modeSpecToggleAction,
+                                               layer=1)
 
                     groupName = choices['groupName']
                     if 'noToolsIcon' not in choices:
@@ -1481,8 +1478,9 @@ class Options(RanaModule):
                                                    smallButtonH,
                                                    None,
                                                    "tools", # tools icon
-                                                   "ml:options:go2ItemToolsMenu:%s;%d;%s" % (
-                                                       groupName, index, variable))
+                                                   "ml:options:go2ItemToolsMenu:%s;%d;%s" %
+                                                   (groupName, index, variable),
+                                                   layer=1)
 
                     border = 20
 
@@ -1496,4 +1494,4 @@ class Options(RanaModule):
                     # in corner: row number
                     indexX = x4 + w * 0.90 - smallButtonW
                     self.menuModule.showText(cr, "%d/%d" % (index + 1, numItems), indexX, y + dy * 0.07,
-                                             w * 0.10 - border, 20)
\ No newline at end of file
+                                             w * 0.10 - border, 20)
