@@ -31,6 +31,7 @@ import time
 import threading
 from core import constants
 from core.point import Point
+from core.signal import Signal
 import core.way as way
 from core.backports.six import u
 from . import routing_providers
@@ -44,16 +45,16 @@ OSD_CURRENT_ROUTE = 2 # a single button that triggers the options menu
 OSD_ROUTE_OPTIONS = 3 # buttons that go to the edit or info menus
 
 
-def getModule(m, d, i):
-    return Route(m, d, i)
+def getModule(*args, **kwargs):
+    return Route(*args, **kwargs)
 
 
 #noinspection PyAttributeOutsideInit
 class Route(RanaModule):
     """Routes"""
 
-    def __init__(self, m, d, i):
-        RanaModule.__init__(self, m, d, i)
+    def __init__(self, *args, **kwargs):
+        RanaModule.__init__(self, *args, **kwargs)
         self._goToInitialState()
         # how long the last routing lookup took in seconds
         self.routeLookupDuration = 0
@@ -76,6 +77,9 @@ class Route(RanaModule):
         # Monav
         self.monav = None
 
+        # signals
+        self.routingDone = Signal()
+
     def _goToInitialState(self):
         """restorer initial routing state
         -> used in init and when rerouting"""
@@ -488,10 +492,15 @@ class Route(RanaModule):
         # the (Google) language code is the second part of
         # this whitespace delimited string
         langCode = langCode.split(" ")[1]
-        if mode == "walk":
-            routeMode = constants.ROUTE_PEDESTRIAN
-        elif mode == "cycle":
-            routeMode = constants.ROUTE_BIKE
+        if self.modrana.gui.getIDString() == "GTK":
+            if mode == "walk":
+                routeMode = constants.ROUTE_PEDESTRIAN
+            elif mode == "cycle":
+                routeMode = constants.ROUTE_BIKE
+        elif self.modrana.gui.getIDString() == "Qt5":
+            # the Qt 5 GUI currently does not use an application wide
+            # mode concept and sets the routing mode separately
+            routeMode = self.get("routingModeQt5", constants.ROUTE_CAR)
         routeParams = routing_providers.RouteParameters(
             routeMode=routeMode,
             avoidTollRoads=self.get("routingAvoidToll", False),
@@ -555,16 +564,13 @@ class Route(RanaModule):
     def _handleRoutingResultCB(self, result):
         # remove any previous route description
         self.text = None
+        # trigger the routing done signal
+        self.routingDone(result)
+
         if result.route and result.returnCode == constants.ROUTING_SUCCESS:
             # process and save routing results
             self.routeLookupDuration = result.lookupDuration
 
-            # save a copy of the route in projection units for faster drawing
-            proj = self.m.get('projection', None)
-            if proj:
-                self.pxpyRoute = [proj.ll2pxpyRel(x[0], x[1]) for x in result.route.getPointsLLE()]
-            self.processAndSaveDirections(result.route)
-
             # set start and destination
             start = result.route.getPointByID(0)
             destination = result.route.getPointByID(-1)
@@ -576,7 +582,16 @@ class Route(RanaModule):
                 self.destination = destination
 
             self.osdMenuState = OSD_CURRENT_ROUTE
-            self.startNavigation()
+
+            # do the GTK GUI specific stuff only when running with GTK GUI
+            if self.modrana.gui.getIDString() == "GTK":
+                # save a copy of the route in projection units for faster drawing
+                proj = self.m.get('projection', None)
+                if proj:
+                    self.pxpyRoute = [proj.ll2pxpyRel(x[0], x[1]) for x in result.route.getPointsLLE()]
+                self.processAndSaveDirections(result.route)
+                self.osdMenuState = OSD_CURRENT_ROUTE
+                self.startNavigation()
 
         else: # routing failed
             self.log.error("routing ended with error")
@@ -594,7 +609,7 @@ class Route(RanaModule):
             elif result.returnCode == constants.ROUTING_ADDRESS_NOT_FOUND:
                 self.notify('start or destination address not found', 3000)
             else:
-                self.notify('offline routing failed', 5000)
+                self.notify('routing failed', 5000)
 
     def getAvailableMonavDataPacks(self):
             """Return all available Monav data packs in the main monav data folder
@@ -829,6 +844,8 @@ class Route(RanaModule):
                 (x, y) = destination
                 (px1, py1) = self.pxpyRoute[-1]
                 (x1, y1) = proj.pxpyRel2xy(px1, py1)
+                cr.set_source_rgba(0, 0, 0.5, 0.45)
+                cr.set_line_width(10)
                 cr.move_to(x, y)
                 cr.line_to(x1, y1)
                 cr.stroke()
@@ -1284,4 +1301,4 @@ class Route(RanaModule):
     def shutdown(self):
         # stop the Monav server, if running
         if self.monav:
-            self.monav.stopServer()
\ No newline at end of file
+            self.monav.stopServer()
